# Developing on local machine


Install the project in your machine like this:


 sudo pip install -e (path)/databricks-rocket


## Build the package and upload it to PyPi


```sh
./cli.py _release_self
```
